@@ -4,11 +4,11 @@
 #' @examples
 #' \dontrun{
 #' setUserDb(),
-#' setUserDb("C:/Users/Documents/PLETHEMUserDb.sqlite")
+#' setUserDb(tempdir())
 #' }
 #' @export
 setUserDb<- function(path = NULL){
-  filters <- matrix(c("SQLite DB",".sqlite"),1,2,byrow = T)
+  filters <- matrix(c("SQLite DB",".sqlite"),1,2,byrow = TRUE)
   if (is.null(path)){
     userDbPath <- getFileFolderPath(type="file",
                       caption = "Select user database",
@@ -28,9 +28,9 @@ setUserDb<- function(path = NULL){
 #' @description The function allows the users to create a new empty user database file that is needed to run plethem.
 #' @param path path to where the user database needs to be stored. Make sure you have write permission to this folder. If no path is provided, it launches a folder select dialog.
 #' @examples
-#' \dontrun{
-#' createEmptyUserDb(),
-#' createEmptyUserDb("C:/Users/Documents/")
+#' if(interactive()){
+#' createEmptyUserDb()
+#' createEmptyUserDb(tempdir())
 #' }
 #' @export
 createEmptyUserDb <- function(path = NULL){
