@@ -14,15 +14,15 @@ performIVIVEUI<- function(namespace){
                                                   choices = c("Human"="ha","Rat"="ra"))
                                    ),
                             column(4,
-                                   numericInput(ns("num_bw"),"Body Weight(kg)",value = 81)
+                                   numericInput(ns("num_bw"),"Body Weight (kg)",value = 81)
                                    ),
                             column(4,
-                                   numericInput(ns("num_livwt"),"Liver Weight(kg)",value = 1.8)
+                                   numericInput(ns("num_livwt"),"Liver Weight (kg)",value = 1.8)
                                    )
                           ),
                           fluidRow(
                             column(3,
-                                   numericInput(ns("num_km"),"Michaelis-Menten Constant (\ub5M)",value = 1)
+                                   numericInput(ns("num_km"),"Michaelis-Menten Constant (uM)",value = 1)
                                    ),
                             column(3,
                                    numericInput(ns("num_hpgl"),"10^6 Hepatocytes per gram liver", value = 0)
@@ -34,7 +34,7 @@ performIVIVEUI<- function(namespace){
                                    numericInput(ns("num_cppgl"),"Cytosolic protein per gram liver",value = 0)
                                    )
                           ),
-                          
+
                           fluidRow(
                                    tabsetPanel(id = ns("heptype"),
                                           tabPanel(title = "Whole Hepatocyte",value = "hep_whole",
@@ -46,25 +46,23 @@ performIVIVEUI<- function(namespace){
                                                      column(4,
                                                             selectizeInput(ns("sel_whunit"),label = "Units",
                                                                            choices = c("L/h"="Lh",
-                                                                                       "L/h/10^6 Hepatocytes"="LhH",
-                                                                                       "\ub5mol/min/10^6 hepatocytes"="ummH")
+                                                                                       "L/h/10^6 Hepatocytes"="LhH")
                                                                            )
                                                             )
-                                                   )                                   
+                                                   )
                                                    ),
                                           tabPanel(title = "Sub-cellular",value = "hep_sc",
-                                               
+
                                                      fluidRow(
                                                        column(4,
                                                               numericInput(ns("num_mscl"),
-                                                                           label = "Measure Microsomal Clearance",
+                                                                           label = "Microsomal Clearance",
                                                                            value = 0)
                                                               ),
                                                        column(4,
                                                               selectizeInput(ns("sel_msunit"),label = "Units",
-                                                                          choices = list("\ub5mol/min/mg Protein"="ummmP",
-                                                                                         "\ub5L/min/mg Protein"="ulmmP",
-                                                                                         "\ub5L/h/mg Protein"="ulhmP",
+                                                                          choices = list("uL/min/mg Protein"="ulmmP",
+                                                                                         "uL/h/mg Protein"="ulhmP",
                                                                                          "mL/min/mg Protein"="mlmmP",
                                                                                          "mL/h/mg Protein"="mlhmP"))
                                                        )
@@ -72,30 +70,30 @@ performIVIVEUI<- function(namespace){
                                                      fluidRow(
                                                        column(4,
                                                               numericInput(ns("num_cycl"),
-                                                                           label = "Measure Cytosolic Clearance",0)
+                                                                           label = "Cytosolic Clearance",0)
 
                                                        ),
                                                        column(4,
                                                               selectizeInput(ns("sel_cyunit"),
                                                                           label = "Units",
-                                                                          choices = list("\ub5L/min/mg Protein"="ulmmP",
-                                                                                         "\ub5L/h/mg Protein"="ulhmP",
+                                                                          choices = list("uL/min/mg Protein"="ulmmP",
+                                                                                         "uL/h/mg Protein"="ulhmP",
                                                                                          "mL/min/mg Protein"="mlmmP",
                                                                                          "mL/h/mg Protein"="mlhmP"))
                                                        )
                                                      )
-                                                   
+
                                           ),
                                           tabPanel(title = "S9 Fraction",value = "hep_s9",
                                                    fluidRow(
                                                      column(4,
                                                             numericInput(ns("num_S9cl"),
-                                                                         "Measured S9 Fraction Clearance",0)
+                                                                         "S9 Fraction Clearance",0)
                                                      ),
                                                      column(4,
                                                             selectizeInput(ns("sel_s9unit"),label = "Units",
-                                                                        choices = list("\ub5L/min/mg Protein"="ulmmP",
-                                                                                       "\ub5L/h/mg Protein"="ulhmP",
+                                                                        choices = list("uL/min/mg Protein"="ulmmP",
+                                                                                       "uL/h/mg Protein"="ulhmP",
                                                                                        "mL/min/mg Protein"="mlmmP",
                                                                                        "mL/h/mg Protein"="mlhmP"))
                                                             )
@@ -105,10 +103,10 @@ performIVIVEUI<- function(namespace){
                                    ),
                           fluidRow(
                             column(4,
-                                   shinyBS::bsButton(ns("btn_reset_metab"),"Reset All Clearance Values",block = T)
+                                   shinyBS::bsButton(ns("btn_reset_metab"),"Reset All Clearance Values",block = TRUE)
                                    ),
                             column(8,
-                                   pickerInput(ns("sel_metabtype"),inline = T,label = "Metabolism Type",
+                                   pickerInput(ns("sel_metabtype"),inline = TRUE,label = "Metabolism Type",
                                                   choices = c("Saturable"="m1","Linear"="m2"))
                             )
                           )
@@ -119,8 +117,8 @@ performIVIVEUI<- function(namespace){
                         )
                         )
             )
-  
-  
+
+
 }
 
 #'server side function for performing IVIVE for a chemical
@@ -173,7 +171,7 @@ performIVIVE <- function(input,output,session,km){
                                                        c(input$sel_msunit,input$sel_cyunit),
                                                        org,age,liver_wt,
                                                        km,mpcppgl,
-                                                       return_total = T),
+                                                       return_total = TRUE),
                    "hep_s9"=calculateScaledS9Clearance(input$num_s9cl,input$sel_s9unit,
                                                        org,age,liver_wt,
                                                        km,mpcppgl),
@@ -187,10 +185,10 @@ performIVIVE <- function(input,output,session,km){
     #print(c(vliv,vmax,km))
     return(c("Yes",vliv/liver_wt,vmax,km))
   }
-  #returnValues$ret_data<- 
+  #returnValues$ret_data<-
   returnValues$ret_data<- eventReactive(input$btn_ivive,module_calcs(),ignoreInit = TRUE,ignoreNULL = TRUE)
-  
-  
+
+
   observeEvent(input$btn_ivive,{
     removeModal()
   })
