@@ -50,7 +50,7 @@ shinyServer(function(input, output,session) {
     modalDialog(
       useShinyjs(),
       # title = "Upload Monte Carlo Results",
-      easyClose = F,#TRUE,
+      easyClose = FALSE,#TRUE,
       size = "l",
       tagList(
         useSweetAlert(),
@@ -169,13 +169,13 @@ shinyServer(function(input, output,session) {
           #                         value = 1000))
           #   ),
           #   fluidRow(
-          #     progressBar(id = "pb",value = 0, status = "success",striped = T)
+          #     progressBar(id = "pb",value = 0, status = "success",striped = TRUE)
           #   )
           # )
         )
       ),
       footer= tagList(
-        uiOutput('mcFooter', inline = T),
+        uiOutput('mcFooter', inline = TRUE),
         modalButton('Cancel')
       )
     )
@@ -243,14 +243,14 @@ shinyServer(function(input, output,session) {
     # shinyjs::enable('addMC')
     inFile <- input$rDataFile
     rDFile <- inFile$datapath
-    loadProject(rDFile,runUI = F)
+    loadProject(rDFile,runUI = FALSE)
     simSet <- projectDbSelect("Select simid,name,descrp from SimulationsSet;")
     # e = new.env()
     # name <- load(rDFile, envir = e)
     # data <- e[['name']]
     # load(rDFile, envir = .GlobalEnv)
     # loadReverseDosimetryProject(rDFile)
-    # simSet <<- SimulationsSet %>%
+    # simSet <- SimulationsSet %>%
     #   filter(
     #     physiovarid > 0 |
     #       chemvarid > 0 |
@@ -396,7 +396,6 @@ shinyServer(function(input, output,session) {
           
           
           results$pbpk <- as.data.frame(mc_results)
-          myResults <<- results$pbpk
           
           # MymcResults <- as.data.frame(mc_results)
           if (input$tissue=="Plasma"){
@@ -422,10 +421,10 @@ shinyServer(function(input, output,session) {
           # mcResults2[n] <- plasmaResults[1]
           if(n==1){#is.null(mcResults)){
             # print('it is null')
-            mcResults <<- plasmaResults
+            mcResults <- plasmaResults
           } else{
             # print('something exists')
-            mcResults <<- cbind(mcResults,plasmaResults)# %>%
+            results$mcResults <- cbind(mcResults,plasmaResults)# %>%
           }
           # mcResults <- mcResults %>% 
           #   rename(
@@ -493,7 +492,7 @@ shinyServer(function(input, output,session) {
       
       output$Plot1 <- renderPlotly({
         p <- plot_ly(
-          stack(mcResults),
+          stack(results$mcResults),
           x = ~ind,
           y = ~values,
           type = "box"
@@ -511,7 +510,7 @@ shinyServer(function(input, output,session) {
           )
       })
       mcvals$exposure <- paste(doseName, ' Concentration (', doseUnits,')', sep = '')
-      mcvals$csvFile <- mcResults
+      mcvals$csvFile <- results$mcResults
       removeModal()
     }
     else{
@@ -526,7 +525,7 @@ shinyServer(function(input, output,session) {
     #print(expoid)
     expotype <- projectDbSelect(sprintf("Select value from Exposure where param = 'expo_sidebar' AND expoid = %f",as.integer(expoid)))
    # print(expotype)
-    # simSet3 <<- simSet %>%
+    # simSet3 <- simSet %>%
     #   filter(
     #     name == input$simulation
     #   )
@@ -535,7 +534,7 @@ shinyServer(function(input, output,session) {
     #     expoid == simSet3$expoid & 
     #       param == 'expo_sidebar'
     #   )
-    # myExpoid <<- exposureType$value[1]
+    # myExpoid <- exposureType$value[1]
     if(expotype == 'oral'){
       mySliderLabel = 'Oral (mg/kg BW/day)'
     } else if(expotype == 'dw'){
@@ -776,7 +775,7 @@ shinyServer(function(input, output,session) {
     input$showpanel
   })
   
-  outputOptions(output, "toggleSidebar", suspendWhenHidden = F)
+  outputOptions(output, "toggleSidebar", suspendWhenHidden = FALSE)
   
   #############################################################################################
   
@@ -897,10 +896,10 @@ shinyServer(function(input, output,session) {
         data = revDosResults$expoEstimates,
         extensions = 'Buttons',
         class = 'cell-border stripe',
-        rownames = F,
+        rownames = FALSE,
         options = list(
-          ordering = F,
-          autoWidth = T,
+          ordering = FALSE,
+          autoWidth = TRUE,
           dom='rtB',
           buttons = list(
             list(
@@ -1011,15 +1010,15 @@ shinyServer(function(input, output,session) {
     #   DT::datatable(
     #     data = userData,
     #     container = sketch,
-    #     rownames = T,
+    #     rownames = TRUE,
     #     extensions = c('FixedColumns','FixedHeader'),
     #     options = list(
-    #       ordering = F,
-    #       autoWidth = T,
-    #       fixedColumns = T,
+    #       ordering = FALSE,
+    #       autoWidth = TRUE,
+    #       fixedColumns = TRUE,
     #       scrollX = '100%',
     #       scrollY = 600,
-    #       scrollCollapse = T, # When scrollY is defined, bottom of table won't "float" below the table
+    #       scrollCollapse = TRUE, # When scrollY is defined, bottom of table won't "float" below the table
     #       pageLength = 50, # How many rows to display by default
     #       # ,dom='rt',
     #       columnDefs = list(
@@ -1057,7 +1056,7 @@ shinyServer(function(input, output,session) {
     #       dlTable1,
     #       file = file,
     #       sep = ",",
-    #       row.names = T,
+    #       row.names = TRUE,
     #       col.names = F
     #     )
     #   }
@@ -1074,7 +1073,7 @@ shinyServer(function(input, output,session) {
     #       dlTable2,
     #       file = file,
     #       sep = ",",
-    #       row.names = T,
+    #       row.names = TRUE,
     #       col.names = F
     #     )
     #   }
@@ -1091,7 +1090,7 @@ shinyServer(function(input, output,session) {
     #       dlTable3,
     #       file = file,
     #       sep = ",",
-    #       row.names = T,
+    #       row.names = TRUE,
     #       col.names = F
     #     )
     #   }
